Flask-Contentful
================

|PyPi| |License|

.. |PyPi| image:: https://badge.fury.io/py/flask-contentful.svg
   :target: https://pypi.python.org/pypi/flask-contentful/
.. |License| image:: https://img.shields.io/badge/license-MIT-blue.svg
   :target: LICENSE
